@@ -47,15 +47,32 @@
 #'                          gamma_cv   = 0.3987261)
 #'
 #' # Posterior sampling:
+#'
+#' rstan_options(auto_write = TRUE)
+#' chains <- 2
+#' options(mc.cores = chains)
+#'
 #' igbm_fit <- stan_igbm(y_data                      = age_specific_mortality_counts,
 #'                       contact_matrix              = aggr_cm,
 #'                       age_distribution_population = aggr_age,
 #'                       age_specific_ifr            = aggr_age_ifr[[3]],
 #'                       itd_distr                   = ditd,
-#'                       likelihood_variance_type    = "quadratic",
+#'                       incubation_period           = 3,
+#'                       infectious_period           = 4,
+#'                       likelihood_variance_type    = "linear",
+#'                       prior_scale_x0              = 0.5,
+#'                       prior_scale_contactmatrix   = 0.05,
+#'                       pi_perc                     = 0.1,
 #'                       prior_volatility            = normal(location = 0, scale = 1),
-#'                       prior_nb_dispersion         = gamma(shape = 2, rate = 1),
-#'                       algorithm_inference         = "optimizing")
+#'                       prior_nb_dispersion         = exponential(rate = 1/5),
+#'                       algorithm_inference         = "sampling",
+#'                       nBurn                       = 5,
+#'                       nPost                       = 10,
+#'                       nThin                       = 1,
+#'                       chains                      = chains,
+#'                       adapt_delta                 = 0.8,
+#'                       max_treedepth               = 16,
+#'                       seed                        = 1)
 #'
 #' # Visualise the posterior distribution of the random contact matrix:
 #' plot_posterior_cm(object = igbm_fit,
@@ -69,6 +86,8 @@ plot_posterior_cm <- function(object, y_data, ...){
 
   if (!isTRUE(check)) stop("Provide an object of class 'stanfit' using rstan::sampling() or rstan::vb()")
 
+  if("theta_tilde" %in% names(object) ) stop("Perform MCMC sampling using rstan::sampling() or rstan::vb()")
+
   posterior_draws <- rstan::extract(object)
   age_grps        <- ncol(y_data[,-c(1:5)])
 
